<style>
    .modal.modal-wide .modal-dialog {
      width: 90%;
    }
    .modal-wide .modal-body {
      overflow-y: auto;
    }

    /* irrelevant styling */
    body p { 
      max-width: 400px; 
      margin: 20px auto; 
    }
    #tallModal .modal-body p { margin-bottom: 900px }
</style>

<div class="modal modal-wide fade" id="{{modal_id}}" style="text-align:center;">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
            <span aria-hidden="true">&times;</span>
        </button>
        <h3>{{modal_title}}</h3>
      </div>
      <div class="modal-body">
        {{content}}
      </div>
    </div>
  </div>
</div>

