{% extends base_site_template %}

{% block title %}Reset password{% endblock %}

{% block content %}
<p>The purpose of this page is to allow you to reset your password in case of 
having forgotten it.</p>
{% if REGISTER %}
<p>If you don't have a password to access this website please consider <a href="{% url 'registration_register' %}">signing-up</a></p>
{% endif %}
<p>By entering the e-mail address with which you registered at the website we will send you a message with a link and a 
token to your address which will allow you to reset your password.<br>
Please follow the instructions there-in.</p>
<form class="form" role="form" method="POST">
	{% csrf_token %}
	{{form.as_div}}
	<input type="submit" name="submit" value="Reset password" class="btn btn-info">
</form>
{% endblock %}

