Dear {{ user.get_full_name}},

You recently issued a password reset request for {{ site_name}}. 
To complete the process, click the link below.

	{{protocol}}://{{domain}}{% url 'password_reset_confirm' uidb64=uid token=token %} 

If you didn’t make this request, it's likely that another user has entered 
your email address by mistake and your account is still secure.

Thanks,
{{ site_name }} support
