{% extends base_site_template %}

{% block title %}Password reset requested{% endblock %}

{% block content %}
<p>You should soon receive a message in the email address you provided, 
containing instructions on how to reset your password.</p>
<p>Please check your inbox.</p>
{% endblock %}

