<div class="accordion-group">
    <div class="accordion-heading">
        <h3><a class="accordion-toggle" data-toggle="collapse" data-parent="#{{parent}}"  href="#collapse{{tag}}">{{ title }}</a></h3>
    </div>

    <div id="collapse{{tag}}" class="accordion-body collapse">
        <div class="accordion-inner">
            {{ content }}
        </div>
    </div>
</div>