{% extends 'base.html' %}
{% load staticfiles %}


{% block breadcrumb %}
<li class="active">Home</li>
{% endblock %}


{% block content %}

<!--
This is where bootstrap starts to get a bit demented.   Surely not all
these divs are needed.
-->

    <div class="row">
        <div class="col-md-6">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">Server Error</h3>
                </div>
                <div class="panel-body">
                    {{exception_detail}}
                </div>
            </div>
        </div>

        <div class="col-md-10">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">Traceback</h3>
                </div>
                <div class="panel-body">
                    <ul>
                    {% for l in traceback %}
                        <li>{{l}}</li>
                    {% endfor %}
                    </ul>
                </div>
            </div>
        </div>
    </div>


{% endblock %}