{% extends base_site_template %}

{% block title %}Password change successful{% endblock %}

{% block content %}
	<h2>Your password was changed</h2>
	<p>Back to <a href="/">Home page</a></p>
{% endblock %}
