<!DOCTYPE html>
<html lang="en-us">
  <head>
    <title>Error 500</title>
    <style type="text/css">
      html, body, div {
	      margin: 0;
	      padding: 0;
      }
      body {
	      font: 12px Arial, sans-serif;
	      line-height: 18px;
	      color: #333333;
	      background: #FFFFFF;
      }
      p {
	      margin: 0;
	      padding-bottom: 10px;
      }
      h1 {
	      font-size: 24px;
	      color: #555555;
	      font-weight: normal;
      }
      #err {
	      position: absolute;
	      left: 150px;
	      top: 150px;
	      border: 2px solid #AAAAAA;
	      padding: 10px;
	      width: 400px;
      }
    </style>
    <meta name="robots" content="NONE,NOARCHIVE" />
  </head>
  <body>
    <div id="err">
      <h1>Error 500: Internal Server Error</h1>
      <p>There is a problem with the page you are trying to reach and it cannot be displayed.</p>
    </div>
  </body>
</html>
