{% extends base_site_template %}

{% block title %}{% if validlink %}Enter your new password{% else %}Token Invalid{% endif %}{% endblock %}

{% block content %}
{% if not validlink %}
	<p>The page you are trying to access does not acknowledge the token being passed through.<br>
	Either the token has expired or you missed transcribing exactly as the original</p>
	<p>If you think this is an error, please contact us</p>
{% else %}
	<p>You can now enter your new password.<br>
	We ask you to enter it twice so as to make sure it's the one you want and is free from accidental mis-typing</p>
	<p>Should you prefer not to proceed, your old password will be preserved.</p>

	<form class="form" role="form" method="POST">
		{% csrf_token %}
		{{form.as_div}}
		<input type="submit" name="submit" value="Reset password" class="btn btn-info">
	</form>
{% endif %}
{% endblock %}

