{% extends base_site_template %}

{% block title %}Password change completed{% endblock %}

{% block content %}
<p>You have successfuly changed your password.</p>
<p>You can now <a href="{{login_url}}">Log-in</a></p>
{% endblock %}

