<div class="modal fade" id={{id}} tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
  <div class="modal-dialog"> 
    <form method="POST" action="{% url post_url %}" class="form modal-content" role="form">
      <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
        <h4 class="modal-title">{{title}}</h4>
      </div>
      <div class="modal-body">
        {% csrf_token %}
        <input type="hidden" value="{{post_id}}" name="{{post_name}}">
          {{ comment_form.as_div }}
      </div>
      <div class="modal-footer">
        <button type="submit" class="btn btn-info" name="submit">{{submit_text}}</button>
        <button type="Cancel" class="btn btn-default pull-left" data-dismiss="modal" name="cancel">Cancel</button>
      </div>
    </form>
  </div>
</div>